"""IO.py
"""

# Abstract Network Simulator ('anx')
#
# Copyright 2017 Vladimir Likic
# Copyright Commonwealth of Australia
#
# This software is licensed under the 3 Clause BSD License:
# https://opensource.org/licenses/BSD-3-Clause
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
# contributors may be used to endorse or promote products derived
# from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

# pylint: disable=invalid-name

from . import Utils


def open_for_reading(file_name):
    """Open file for reading
    """

    if not Utils.is_str(file_name):
        Utils.error("'{:s}' is not a string".format(file_name))
    try:
        fp = open(file_name)
    except IOError:
        Utils.error("'{:s}' does not exist".format(file_name))

    return fp


def open_for_writing(file_name):
    """Open file for writing
    """

    if not Utils.is_str(file_name):
        Utils.error("'{:s}' is not a string".format(file_name))
    try:
        fp = open(file_name, "w")
    except IOError:
        Utils.error("Cannot open '{:s}' for writing".format(file_name))

    return fp


def close_for_reading(fp):
    """Close file opened for reading
    """

    fp.close()


def close_for_writing(fp):

    """Close file opened for reading
    """

    fp.close()


def file_lines(file_name):

    """Return all file lines, with some filtering
    """

    fp = open_for_reading(file_name)
    lines = fp.readlines()
    close_for_reading(fp)

    # remove whitespaces
    lines2 = Utils.strip_wsnl_list(lines)

    # remove empty lines
    lines3 = []
    for line in lines2:
        if line != "":
            lines3.append(line)

    return lines3
